@@ -34,13 +34,12 @@ double eta(int m,int d,double r)
    wiggliness penalty. */
 
 { static int first=1;
-  static double pi,rpi,Ghalf;
+  static double pi,Ghalf;
   double f;
   int i,k;
   if (first)
   { first=0;
     pi=asin(1.0)*2.0; 
-    rpi=sqrt(pi);
     Ghalf=sqrt(pi);   /* Gamma function of 0.5 */
   }
   if (2*m<=d) ErrorMessage(_("You must have 2m>d for a thin plate spline."),1);
@@ -256,12 +255,10 @@ int *Xd_strip(matrix *Xd)
 */
 
 { int *yxindex,start,stop,ok,i;
-  long Xdor;
   double xi,**dum;
   yxindex = (int *)calloc((size_t)Xd->r,sizeof(int));
   dum = (double **)calloc((size_t)Xd->r,sizeof(double *));
   msort(*Xd);
-  Xdor=Xd->r; /* keep record of original length of Xd */
   start=stop=0;ok=1;
   while(ok)
   { /* look for start of run of equal rows ..... */
@@ -348,7 +345,9 @@ void tprs_setup(double **x,double **knt,int m,int d,int n,int k,int constant,mat
 { matrix X1,E,U,v,TU,T,Z,p;
  
   int l,i,j,M,*yxindex,pure_knot=0,nk,minus=-1,kk;
-  double w,*xc,*XMi,**UZM,*X1V,*Ea,*Ua;
+  double w,*xc,*XMi,**UZM,*X1V,*Ea,*Ua,tol=DOUBLE_EPS;
+  tol = pow(tol,.7);
+
   if (n_knots<k) /* then use the covariate points as knots */
   { *Xu=initmat((long)n,(long)d+1);
     for (i=0;i<n;i++) { for (j=0;j<d;j++) Xu->M[i][j]=x[j][i];Xu->M[i][d]=(double)i;}
@@ -397,7 +396,7 @@ void tprs_setup(double **x,double **knt,int m,int d,int n,int k,int constant,mat
       RArrayFromMatrix(Ea,nk,&E);
       minus = -1;kk=k; 
   
-      Rlanczos(Ea,Ua,v.M[0],&nk, &kk, &minus);
+      Rlanczos(Ea,Ua,v.M[0],&nk, &kk, &minus,&tol);
 
       U = Rmatrix(Ua,E.r,k);free(Ea);free(Ua);
     
